<?php

namespace Slack\Console\Commands;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;
use React\EventLoop\Loop;
use Slack\Client\SocketMode;
use Slack\Command\Factory as SlackCommandFactory;
use Slack\Event\Factory as SlackEventFactory;
use Slack\Interactive\Factory as SlackInteractiveFactory;

class SlackSocketClient extends Command
{
	private const LOGKEY = 'SSC';

	/**
	 * The name and signature of the console command.
	 *
	 * @var string
	 */
	protected $signature = 'slack:socketmode';

	/**
	 * The console command description.
	 *
	 * @var string
	 */
	protected $description = 'Start SocketMode Client';

	/**
	 * Execute the console command.
	 *
	 * @return void
	 * @throws \Exception
	 */
	public function handle()
	{
		// Make sure our socket_token is defined
		if (! config('slack.socket_token'))
			throw new \Exception('SocketMode Client Token not defined.');

		$loop = Loop::get();

		$client = new SocketMode($loop);
		$client->setToken(config('slack.socket_token'));

		$client->on('events_api',function ($data) {
			event(SlackEventFactory::make($data));
		});

		$client->on('interactive',function ($data) {
			event(SlackInteractiveFactory::make($data));
		});

		$client->on('slash_command',function ($data) {
			event(SlackCommandFactory::make($data));
		});

		$client->connect()->then(function () {
			Log::debug(sprintf('%s:- Connected to slack.',self::LOGKEY));
		});

		$loop->run();
	}
}
