<?php

namespace Slack\Event;

/**
 * This class handles message responses received from Slack
 * These events come as messages on a thread, or new messages posted in the main stream.
 * There are also subtype events, representing deletion and broadcasting
 *
 * EG:
 * [token] => {SLACKTOKEN}
 * [team_id] => {SLACKTEAM}
 * [api_app_id] => A4TCZ007N
 * [event] => stdClass Object
 * (
 *   [client_msg_id] => f49c853e-8958-4f8d-b8ed-fe2c302755de
 *   [type] => message
 *   [subtype] => message_deleted
 *   [text] => foo
 *   [user] => {SLACKUSER}
 *   [ts] => 1599718357.012700
 *   [team] => {SLACKTEAM}
 *   [blocks] => Array
 *   (
 *      ...
 *   )
 *   [thread_ts] => 1598854309.005800
 *   [parent_user_id] => {SLACKUSER}
 *   [channel] => {SLACKCHANNEL}
 *   [event_ts] => 1599718357.012700
 *   [channel_type] => group
 * )
 * [type] => event_callback
 * [event_id] => Ev01AE1G2402
 * [event_time] => 1599718357
 * [authed_users] => Array
 * (
 *    ...
 * )
 */
class Message extends Base
{
	public function __get($key)
	{
		switch ($key) {
			case 'channel_id':
				return object_get($this->_data,'event.channel');
			case 'user_id':
				return object_get($this->_data,'event.user');
			case 'type':
				return object_get($this->_data,'event.subtype');

			case 'thread_ts':
				return object_get($this->_data,'event.'.($this->type == 'message_deleted' ? 'previous_message.' : '').$key);

			case 'deleted_ts':
			case 'text':
			case 'ts':
				return object_get($this->_data,'event.'.$key);

			default:
				return parent::__get($key);
		}
	}
}
