<?php

namespace Slack\Event;

/**
 * This class handles Pin Added responses received from Slack
 *
 * EG:
 * [token] => {SLACKTOKEN}
 * [team_id] => {SLACKTEAM}
 * [api_app_id] => A4TCZ007N
 * [event] => stdClass Object
 * (
 *   [type] => pin_added
 *   [user] => {SLACKUSER}
 *   [channel_id] => {SLACKCHANNEL}
 *   [item] => stdClass Object
 *   (
 *     [type] => message
 *     [created] => 1599637814
 *     [created_by] => {SLACKUSER}
 *     [channel] => {SLACKCHANNEL}
 *     [message] => stdClass Object
 *     (
 *       [bot_id] => B4TC0EYKU
 *       [type] => message
 *       [text] =>
 *       [user] => {SLACKUSER}
 *       [ts] => 1599617180.008300
 *       [team] => {SLACKTEAM}
 *       [bot_profile] => stdClass Object
 *       (
 *          ...
 *       )
 *       [pinned_to] => Array
 *       (
 *         [0] => G4D0B9B7V
 *       )
 *       [permalink] => https://leenooks.slack.com/archives/G4D0B9B7V/p1599617180008300
 *     )
 *   )
 *   [item_user] => {SLACKUSER}
 *   [pin_count] => 25
 *   [pinned_info] => stdClass Object
 *   (
 *     [channel] => {SLACKCHANNEL}
 *     [pinned_by] => {SLACKUSER}
 *     [pinned_ts] => 1599637814
 *   )
 *   [event_ts] => 1599637814.008900
 * )
 * [type] => event_callback
 * [event_id] => Ev01AHHE5TS8
 * [event_time] => 1599637814
 * [authed_users] => Array
 * (
 *   [0] => {SLACKUSER}
 * )
 */
class PinAdded extends Base
{
	public function __get($key)
	{
		switch ($key) {
			case 'user_id':
				return object_get($this->_data,'event.user');

			case 'ts':
				return object_get($this->_data,'event.item.message.ts');

			case 'channel_id':
				return object_get($this->_data,'event.'.$key);

			default:
				return parent::__get($key);
		}
	}
}
