<?php

namespace Slack\Event;

/**
 * This class handles Pin Removed responses received from Slack
 *
 * EG:
 * [token] => {SLACKTOKEN}
 * [team_id] => {SLACKTEAM}
 * [api_app_id] => A4TCZ007N
 * [event] => stdClass Object
 * (
 *   [type] => pin_removed
 *   [user] => {SLACKUSER}
 *   [channel_id] => {SLACKCHANNEL}
 *   [item] => stdClass Object
 *   (
 *     [type] => message
 *     [created] => 1599550210
 *     [created_by] => {SLACKUSER}
 *     [channel] => {SLACKCHANNEL}
 *     [message] => stdClass Object
 *     (
 *       [bot_id] => {SLACKUSER}
 *       [type] => message
 *       [text] =>
 *       [user] => {SLACKUSER}
 *       [ts] => 1599550210.007600
 *       [team] => {SLACKTEAM}
 *       [bot_profile] => stdClass Object
 *       (
 *         ...
 *       )
 *     )
 *     [permalink] => https://leenooks.slack.com/archives/G4D0B9B7V/p1599550210007600
 *   )
 *   [item_user] => {SLACKUSER}
 *   [pin_count] => 24
 *   [pinned_info] => stdClass Object
 *   (
 *     [channel] => {SLACKCHANNEL}
 *     [pinned_by] => {SLACKUSER}
 *     [pinned_ts] => 1599550210
 *   )
 *   [has_pins] => 1
 *   [event_ts] => 1599636527.008800
 * )
 * [type] => event_callback
 * [event_id] => Ev01A887TPRT
 * [event_time] => 1599636527
 * [authed_users] => Array
 * (
 *   ...
 * )
 */
class PinRemoved extends Base
{
	public function __get($key)
	{
		switch ($key) {
			case 'user_id':
				return object_get($this->_data,'event.user');

			case 'ts':
				return object_get($this->_data,'event.item.message.ts');

			case 'channel_id':
				return object_get($this->_data,'event.'.$key);

			default:
				return parent::__get($key);
		}
	}
}
