<?php

namespace Slack\Event;

/**
 * This class handles when the user adds a reaction to a message
 *
 * EG:
 * [token] => {SLACKTOKEN}
 * [team_id] => {SLACKTEAM}
 * [api_app_id] => A4TCZ007N
 * [event] => stdClass Object
 * (
 *   [type] => reaction_added
 *   [user] => {SLACKUSER}
 *   [item] => stdClass Object
 *   (
 *     [type] => message
 *     [channel] => {SLACKCHANNEL}
 *     [ts] => 1598854309.005800
 *   )
 *   [reaction] => question
 *   [item_user] => {SLACKUSER}
 *   [event_ts] => 1599709789.010500
 * )
 * [type] => event_callback
 * [event_id] => Ev01ADSDSE74
 * [event_time] => 1599709789
 * [authed_users] => Array
 * (
 *   ...
 * )
 */
class ReactionAdded extends Base
{
	public function __get($key)
	{
		switch ($key) {
			case 'user_id':
				return object_get($this->_data,'event.user');

			case 'reaction':
				return object_get($this->_data,'event.'.$key);

			case 'channel_id':
				return object_get($this->_data,'event.item.channel');

			case 'ts':
				return object_get($this->_data,'event.item.ts');

			default:
				return parent::__get($key);
		}
	}
}
