<?php

namespace Slack\Interactive;

use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Log;
use Slack\Client\Payload;

class Factory {
	private const LOGKEY = 'SIF';

	/**
	 * @var array event type to event class mapping
	 */
	public const map = [
		'block_actions'=>BlockActions::class,
		'interactive_message'=>InteractiveMessage::class,
		'shortcut'=>Shortcut::class,
		'view_closed'=>ViewClosed::class,
		'view_submission'=>ViewSubmission::class,
	];

	/**
	 * Returns new event instance
	 *
	 * @param string $type
	 * @param array  $request
	 * @return Base
	 */
	public static function create(string $type,array $request): Base
	{
		$class = Arr::get(self::map,$type,Unknown::class);
		Log::debug(sprintf('%s:Working out Interactive Message Event Class for [%s] as [%s]',static::LOGKEY,$type,$class),['m'=>__METHOD__]);

		if (App::environment() == 'local')
			file_put_contents('/tmp/interactive.'.$type,print_r($request,TRUE));

		return new $class($request);
	}

	public static function make(Payload $request): Base
	{
		// During the life of the event, this method is called twice - once during Middleware processing, and finally by the Controller.
		static $o = NULL;
		static $or = NULL;

		if (! $o OR ($or != $request)) {
			$or = $request;
			$o = self::create(Arr::get($request->getData(),'payload.type'),Arr::get($request->getData(),'payload'));
		}

		return $o;
	}
}
