<?php

namespace Slack\Jobs;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Log;
use Slack\Models\{Channel,User};
use Slack\Exceptions\SlackException;

class DeleteChat extends Job
{
	private const LOGKEY = 'JDC';

	/**
	 * Create a new job instance.
	 *
	 * @param Model  $o
	 * @param string $ts
	 * @throws \Exception
	 */
	public function __construct(Model $o,string $ts)
	{
		if ($o instanceof Channel) {
			$this->_data['cid'] = $o->channel_id;

		} elseif ($o instanceof User) {
			$this->_data['cid'] = $o->user_id;

		} else
			throw new \Exception('Invalid Model: '.get_class($o));

		$this->_data['to'] = $o->team;
		$this->_data['ts'] = $ts;
	}

	/**
	 * Execute the job.
	 *
	 * @return void
	 * @throws \Exception
	 */
	public function handle()
	{
		Log::info(sprintf('%s:Start - Delete Chat in Channel [%s] with TS [%s]',static::LOGKEY,$this->cid,$this->ts),['m'=>__METHOD__]);

		try {
			$this->to->slackAPI()->deleteChat($this->cid,$this->ts);

			Log::debug(sprintf('%s:Deleted Slack Message: %s',static::LOGKEY,$this->ts),['m'=>__METHOD__]);

		} catch (SlackException $e) {
			Log::error(sprintf('%s:Failed to delete slack message [%s] [%s]',static::LOGKEY,$this->ts,$e->getMessage()),['m'=>__METHOD__]);
		}
	}
}
