<?php

namespace Slack\Listeners;

use Illuminate\Support\Facades\Log;
use Slack\Jobs\DeleteChat;
use Slack\Interactive\BlockActions;

class BlockActionListener
{
	protected const LOGKEY = 'LBA';

	// Block actions arent queued, since slack expects a response to the request
	//public $queue = 'high';

	/**
	 * Handle the event.
	 *
	 * @param BlockActions $event
	 * @return void
	 * @throws \Exception
	 */
	public function handle(BlockActions $event): void
	{
		// Do some magic with event data
		Log::info(sprintf('%s:Block Action for Callback [%s] User [%s] in [%s]',self::LOGKEY,$event->callback_id,$event->user_id,$event->team_id),['m'=>__METHOD__]);

		switch ($event->callback_id) {
			// Messages that generate a block action dont have a callback ID
			case NULL:
				Log::debug(sprintf('%s:Callback NULL [%s] (%s)',self::LOGKEY,$event->isMessage(),$event->action_id),['m'=>__METHOD__]);

				$this->messageEvent($event);
				break;

			default:
				Log::notice(sprintf('%s:Unhandled CALLBACK [%s]',self::LOGKEY,$event->callback_id),['m'=>__METHOD__]);
		}
	}

	/**
	 * Events from messages
	 *
	 * @param BlockActions $event
	 * @throws \Exception
	 */
	protected function messageEvent(BlockActions $event): void
	{
		Log::info(sprintf('%s:[%s] has [%d] actions',self::LOGKEY,$event->callback_id,count($event->actions)),['m'=>__METHOD__]);

		foreach ($event->actions as $id => $action) {
			$event->index = $id;

			Log::debug(sprintf('%s:Action [%s]',self::LOGKEY,$event->action_id),['m'=>__METHOD__]);
			switch ($event->action_id) {
				case 'self_destruct':
					// Queue the delete of the message
					dispatch((new DeleteChat($event->user(),$event->message_ts))->onQueue('low'));

					// @todo If this message is on integrations messages channel, which is not the user_id() - need to use the user's integration direct channel ID
					break;

				default:
					Log::notice(sprintf('%s:Unhandled ACTION [%s]',self::LOGKEY,$event->action_id),['m'=>__METHOD__]);
			}
		}
	}

	/**
	 * Store data coming in from a block action dialog
	 *
	 * @param BlockActions $event
	 */
	protected function store(BlockActions $event): void
	{
		foreach ($event->actions as $id => $action) {
			$event->index = $id;

			switch ($event->action_id) {
				default:
					Log::notice(sprintf('%s:Unhandled ACTION [%s]',static::LOGKEY,$event->action_id),['m'=>__METHOD__]);
			}
		}
	}
}
