<?php

namespace Slack\Listeners;

use Illuminate\Support\Facades\Log;
use Illuminate\Contracts\Queue\ShouldQueue;

use Slack\Event\Message;

class MessageListener implements ShouldQueue
{
	protected const LOGKEY = 'LM-';

	public $queue = 'high';

	/**
	 * Handle the event.
	 *
	 * @param Message $event
	 * @return void
	 */
	public function handle(Message $event)
	{
		// Do some magic with event data
		Log::info(sprintf('%s:Message event [%s] - subtype [%s]',self::LOGKEY,$event->ts,$event->type),['m'=>__METHOD__]);

		switch ($event->type) {
			case 'channel_join':    // Handled by another event (member_joined_channel - needs to be defined in Event Subscriptions)
			case 'group_join':      // Handled by another event (member_joined_channel - needs to be defined in Event Subscriptions)
			case 'message_changed':
				Log::debug(sprintf('%s:Ignoring message subtype [%s]',self::LOGKEY,$event->type),['m'=>__METHOD__]);
				break;

			default:
				Log::notice(sprintf('%s:Unhandled TYPE [%s]',self::LOGKEY,$event->type),['m'=>__METHOD__]);
		}
	}
}
