<?php

namespace App\Listeners;

use Illuminate\Support\Facades\Log;
use Slack\Blockkit\Blocks;
use Slack\Blockkit\Modal;
use Slack\Interactive\Shortcut;
use Slack\Message;

class ShortcutListener //implements ShouldQueue
{
	protected const LOGKEY = 'LSC';

	// Block actions arent queued, since slack expects a response to the request
	//public $queue = 'high';

	/**
	 * Handle the event.
	 *
	 * @param Shortcut $event
	 * @return void
	 * @todo To Test
	 */
	public function handle(Shortcut $event): Message
	{
		if (! $event->channel() || ! $event->channel()->active) {
			$modal = new Modal(Blocks\TextEmoji::item(config('app.name')));
			$blocks = new Blocks;

			$blocks->addHeader(':robot_face: Bot not in this channel');
			$blocks->addSectionText(Blocks\Text::item('Please add the BOT to this channel and try this again.'));

			$modal->setBlocks($blocks);

			try {
				$event->team()->slackAPI()->viewOpen($event->trigger_id,json_encode($modal));

			} catch (\Exception $e) {
				Log::error(sprintf('%s:Got an error posting view to slack: %s',static::LOGKEY,$e->getMessage()),['m'=>__METHOD__]);
			}

			return (new Message)->blank();
		}

		// Do some magic with event data
		Log::info(sprintf('%s:Shortcut [%s] triggered for: [%s]',self::LOGKEY,$event->callback_id,$event->team_id),['m'=>__METHOD__]);

		switch ($event->callback_id) {
			default:
				Log::notice(sprintf('%s:Unhandled CALLBACK [%s]',self::LOGKEY,$event->callback_id),['m'=>__METHOD__]);
		}
	}
}
