<?php

namespace Slack\Message;

/**
 * Class MessageAttachmentAction - Slack Message Attachments Actions
 * Represents an Single Action for a Slack Message Attachment
 *
 * @package Slack\Message
 */
class AttachmentAction implements \JsonSerializable
{
	private $_data;

	public function __construct()
	{
		$this->_data = collect();
	}

	public function jsonSerialize()
	{
		return $this->_data;
	}

	public function minSize(int $int): self
	{
		$this->_data->put('min_query_length',$int);

		return $this;
	}

	/**
	 * Set a confirmation diaglog when this action is selected
	 *
	 * @param string $title
	 * @param string $text
	 * @param string $ok_text
	 * @param string $dismiss_text
	 * @return $this
	 */
	public function setConfirm(string $title,string $text,string $ok_text,string $dismiss_text): self
	{
		$this->_data->put('confirm',[
			'title'=>$title,
			'text'=>$text,
			'ok_text'=>$ok_text,
			'dismiss_text'=>$dismiss_text
		]);

		return $this;
	}

	/**
	 * Set the name of the action
	 *
	 * @param string $string
	 * @return $this
	 */
	public function setName(string $string): self
	{
		$this->_data->put('name',$string);

		return $this;
	}

	/**
	 * Set the text displayed in the action
	 *
	 * @param string $type
	 * @return $this
	 */
	public function setStyle(string $style): self
	{
		if (! in_array($style,['danger','primary']))
			abort(500,'Style not supported: '.$style);

		$this->_data->put('style',$style);

		return $this;
	}

	/**
	 * Set the text displayed in the action
	 *
	 * @param string $string
	 * @return $this
	 */
	public function setText(string $string): self
	{
		$this->_data->put('text',$string);

		return $this;
	}

	/**
	 * Set the text displayed in the action
	 *
	 * @param string $type
	 * @return $this
	 */
	public function setType(string $type): self
	{
		if (! in_array($type,['button','select']))
			abort(500,'Type not supported: '.$type);

		$this->_data->put('type',$type);

		return $this;
	}

	/**
	 * Set the value for the action
	 *
	 * @param string $string
	 * @return $this
	 */
	public function setValue(string $string): self
	{
		$this->_data->put('value',$string);

		return $this;
	}

	public function source(string $string): self
	{
		if (! in_array($string,['external']))
			abort(500,'Dont know how to handle: '.$string);

		$this->_data->put('data_source',$string);

		return $this;
	}
}
