<?php

namespace Slack\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Collection;
use Leenooks\Traits\ScopeActive;

class Token extends Model
{
	use ScopeActive;

	protected $table = 'slack_tokens';

	/* RELATIONS */

	public function team()
	{
		return $this->belongsTo(Team::class);
	}

	/* ATTRIBUTES */

	public function getScopesAttribute(): Collection
	{
		return collect(explode(',',$this->scope));
	}

	public function getTokenHiddenAttribute(): string
	{
		return '...'.substr($this->token,-5);
	}

	/* METHODS */

	/**
	 * Does this token include a specific scope
	 *
	 * @param string|null $scope
	 * @return bool
	 */
	public function hasScope(?string $scope): bool
	{
		return ($scope AND ($this->getScopesAttribute()->search($scope) !== FALSE));
	}
}
