<?php

namespace Slack\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Log;
use Leenooks\Traits\ScopeActive;

class User extends Model
{
	use ScopeActive;

	private const LOGKEY = '-MU';

	protected $fillable = ['user_id'];
	protected $table = 'slack_users';

	/* RELATIONS */

	public function enterprise()
	{
		return $this->belongsTo(Enterprise::class);
	}

	/* ATTRIBUTES */

	/**
	 * Return the user in slack response format
	 */
	public function getSlackUserAttribute(): string
	{
		return sprintf('<@%s>',$this->user_id);
	}

	/**
	 * Return the team that this user is in - normally required to get the team token
	 * For enterprise users, any team token will do.
	 *
	 * If the integration is not installed in any channels, team will be blank
	 *
	 * @return mixed
	 */
	public function getTeamAttribute(): ?Team
	{
		Log::debug(sprintf('%s:User [%s]',self::LOGKEY,$this->id),['team'=>$this->team_id,'enterprise'=>$this->enterprise_id,'eo'=>$this->enterprise]);

		return $this->team_id ? Team::find($this->team_id) : (($x=$this->enterprise->teams) ? $x->first() : NULL);
	}
}
