<?php

namespace Slack\Providers;

use Illuminate\Notifications\ChannelManager;
use Illuminate\Support\Facades\Notification;
use Illuminate\Support\ServiceProvider;
use Slack\API;
use Slack\Channels\SlackBotChannel;
use Slack\Console\Commands\SlackSocketClient;

class SlackServiceProvider extends ServiceProvider
{
	/**
	 * Bootstrap the application services.
	 *
	 * @return void
	 */
	public function boot()
	{
		if ($this->app->runningInConsole()) {
			if (config('slack.run_migrations')) {
				$this->loadMigrationsFrom(__DIR__.'/../database/migrations');
			}

			$this->commands([
				SlackSocketClient::class,
			]);
		}
	}

	/**
	 * Register the application services.
	 *
	 *  @return void
	 */
	public function register()
	{
		$this->mergeConfigFrom(__DIR__.'/../config/slack.php','slack');

		$this->loadRoutesFrom(realpath(__DIR__ .'/../routes.php'));

		if (config('slack.register_notification'))
			Notification::resolved(function (ChannelManager $service) {
				$service->extend('slackapp',function($app) {
					return new SlackBotChannel($app->make(API::class));
				});
			});
	}
}