<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class SlackIntegration extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
	    Schema::create('slack_enterprises', function (Blueprint $table) {
		    $table->id();
		    $table->timestamps();

		    $table->string('enterprise_id', 45)->unique();
		    $table->string('name')->nullable();
		    $table->boolean('active');
	    });

	    Schema::create('slack_users', function (Blueprint $table) {
		    $table->id();
		    $table->timestamps();

		    $table->string('user_id', 45)->unique();
		    $table->string('name')->nullable();
		    $table->boolean('active');
		    $table->boolean('admin');

		    $table->integer('enterprise_id')->nullable()->unsigned();
		    $table->foreign('enterprise_id')->references('id')->on('slack_enterprises');
	    });

	    Schema::create('slack_teams', function (Blueprint $table) {
		    $table->id();
		    $table->timestamps();

		    $table->string('team_id', 45)->unique();
		    $table->string('team_name')->nullable();
		    $table->string('description')->nullable();
		    $table->boolean('active');

		    $table->integer('bot_id')->nullable()->unsigned();
		    $table->foreign('bot_id')->references('id')->on('slack_users');

		    $table->integer('admin_id')->nullable()->unsigned();
		    $table->foreign('admin_id')->references('id')->on('slack_users');

		    $table->integer('enterprise_id')->nullable()->unsigned();
		    $table->foreign('enterprise_id')->references('id')->on('slack_enterprises');
	    });

	    Schema::create('slack_channels', function (Blueprint $table) {
		    $table->id();
		    $table->timestamps();

		    $table->string('channel_id', 45)->unique();
		    $table->string('name')->nullable();
		    $table->boolean('active');

		    $table->integer('team_id')->nullable()->unsigned();
		    $table->foreign('team_id')->references('id')->on('slack_teams');
	    });

	    Schema::table('slack_users', function (Blueprint $table) {
		    $table->integer('team_id')->nullable()->unsigned();
		    $table->foreign('team_id')->references('id')->on('slack_teams');
	    });

	    Schema::create('slack_tokens', function (Blueprint $table) {
		    $table->id();
		    $table->timestamps();

		    $table->string('token');
		    $table->string('scope')->nullable();
		    $table->boolean('active');
		    $table->string('description')->nullable();

		    $table->integer('team_id')->unique()->unsigned();
		    $table->foreign('team_id')->references('id')->on('slack_teams');
	    });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
	    Schema::table('slack_users', function (Blueprint $table) {
	    	$table->dropForeign(['team_id']);
		    $table->dropColumn(['team_id']);
	    });

	    Schema::dropIfExists('slack_tokens');
	    Schema::dropIfExists('slack_channels');
	    Schema::dropIfExists('slack_teams');
	    Schema::dropIfExists('slack_users');
        Schema::dropIfExists('slack_enterprises');
    }
}
